==> drv_vmmc-1.7.0.tar.gz: drv_vmmc-1.7.0/src/drv_vmmc_gr909.h <==
#ifndef _DRV_VMMC_GR909_H
#define _DRV_VMMC_GR909_H
/******************************************************************************

                              Copyright (c) 2009
                            Lantiq Deutschland GmbH
                     Am Campeon 3; 85579 Neubiberg, Germany

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

******************************************************************************/

/**
   \file drv_vmmc_gr909.h
*/

/* ========================================================================== */
/*                                 Includes                                   */
/* ========================================================================== */

/* ========================================================================== */
/*                             Macro definitions                              */
/* ========================================================================== */

/* ========================================================================== */
/*                             Type definitions                               */
/* ========================================================================== */

/* ========================================================================== */
/*                           Function prototypes                              */
/* ========================================================================== */
extern IFX_int32_t VMMC_TAPI_LL_ALM_GR909_Start (IFX_TAPI_LL_CH_t *pLLChannel,
                                        IFX_TAPI_GR909_START_t *p_start);
extern IFX_int32_t VMMC_TAPI_LL_ALM_GR909_Stop (IFX_TAPI_LL_CH_t *pLLChannel);
extern IFX_int32_t VMMC_TAPI_LL_ALM_GR909_Result (IFX_TAPI_LL_CH_t *pLLChannel,
                                        IFX_TAPI_GR909_RESULT_t *pResults);
#endif /* _DRV_VMMC_GR909_H */

==> drv_vmmc-1.10.3.5.tar.gz: drv_vmmc-1.10.3.5/src/drv_vmmc_gr909.h <==
#ifndef _DRV_VMMC_GR909_H
#define _DRV_VMMC_GR909_H
/******************************************************************************

                              Copyright (c) 2009
                            Lantiq Deutschland GmbH
                     Am Campeon 3; 85579 Neubiberg, Germany

  For licensing information, see the file 'LICENSE' in the root folder of
  this software module.

******************************************************************************/

/**
   \file drv_vmmc_gr909.h
*/

/* ========================================================================== */
/*                                 Includes                                   */
/* ========================================================================== */

/* ========================================================================== */
/*                             Macro definitions                              */
/* ========================================================================== */

/* ========================================================================== */
/*                             Type definitions                               */
/* ========================================================================== */

/* ========================================================================== */
/*                           Function prototypes                              */
/* ========================================================================== */
extern IFX_int32_t VMMC_TAPI_LL_ALM_GR909_Start (IFX_TAPI_LL_CH_t *pLLChannel,
                                        IFX_TAPI_GR909_START_t const *p_start);
extern IFX_int32_t VMMC_TAPI_LL_ALM_GR909_Stop (IFX_TAPI_LL_CH_t *pLLChannel);
extern IFX_int32_t VMMC_TAPI_LL_ALM_GR909_Result (IFX_TAPI_LL_CH_t *pLLChannel,
                                        IFX_TAPI_GR909_RESULT_t *pResults);
#endif /* _DRV_VMMC_GR909_H */
